static
==================================================
**Module**: :mod:`espressodb.base.static`

.. automodule:: espressodb.base.static

Contained static file packages are

* https://fontawesome.com
* https://katex.org
* https://github.com/google/code-prettify
